"use strict";
// https://reactjs.org/docs/react-without-es6.html
// https://levelup.gitconnected.com/ultimate-react-component-patterns-with-typescript-2-8-82990c516935
Object.defineProperty(exports, "__esModule", { value: true });
var CryptoJS = require("crypto-js");
const React = require("react");
const react_redux_1 = require("react-redux");
require("../style/index.css");
const PasswordSelector_1 = require("./PasswordSelector");
const credentials_1 = require("./ducks/credentials");
const token_1 = require("./ducks/token");
const CredentialsList = (props) => {
    //console.log(props.credentials);
    props.setAddCredentialListener(props.addCredential);
    props.setCredentialListGetter(() => props.credentials);
    props.setSetCredentialsListener((credentials) => {
        //console.log(credentials);
        for (let key in Object.keys(credentials)) {
            props.setCredential(credentials[key].id, credentials[key].tag, credentials[key].value, false);
        }
    });
    props.setSetLastIdListener((lastId) => {
        if (lastId !== undefined)
            props.setLastId(lastId);
    });
    props.setLastIdGetter(() => props.lastId);
    props.setOnSavedListener(() => {
        for (let key in Object.keys(props.credentials)) {
            let credential = props.credentials[key];
            //console.log(credential);
            props.setCredential(credential.id, credential.tag, credential.value, false);
        }
    });
    props.setOnStopListener(() => {
        props.setActiveToken("");
    });
    //console.log(props.argtoken);
    //console.log(props.token);
    return props.isConnected ? (props.argtoken !== undefined && props.argtoken === props.token ? React.createElement("table", { className: "jp-CredentialsTable" },
        React.createElement("tbody", null,
            React.createElement("tr", null,
                React.createElement("th", null),
                React.createElement("th", null, "Key"),
                React.createElement("th", null, "Value"),
                React.createElement("th", { className: "jp-Column" })),
            props.credentials.map(credential => React.createElement("tr", null,
                React.createElement("td", { className: "jp-StarColumn" }, credential.changed ? "*" : ""),
                React.createElement("td", { className: "jp-Cell" },
                    React.createElement("input", { className: "jp-Input", type: "text", value: credential.tag !== undefined ? credential.tag : "", onChange: (event) => props.setCredential(credential.id, event.target.value, credential.value, true) })),
                React.createElement("td", { className: "jp-Cell" },
                    React.createElement("input", { className: "jp-Input", type: "text", value: credential.value !== undefined ? credential.value : "", onChange: (event) => props.setCredential(credential.id, credential.tag, event.target.value, true) })),
                React.createElement("td", { className: "jp-Column" },
                    React.createElement("button", { className: "jp-Button", onClick: () => {
                            props.removeCredential(credential.id);
                            props.onRemoveCredential(credential.tag);
                        } }, "Delete")))),
            " ")) : React.createElement(PasswordSelector_1.default, { argToken: props.argtoken, onTokenSet: props.onTokenSet })) : React.createElement("div", { className: "jp-Frame" },
        React.createElement("h2", null, "Credential Store"),
        React.createElement("p", null, "You need to log in to set and access your credentials. Please click on the key above..."));
};
function mapStateToProps(state, props) {
    return {
        credentials: credentials_1.getCredentials(state),
        lastId: credentials_1.getLastId(state),
        token: CryptoJS.SHA256(token_1.getActiveToken(state)).toString(),
    };
}
function mapDispatchToProps(dispatch, props) {
    return {
        addCredential: () => {
            dispatch(credentials_1.addCredential());
        },
        removeCredential: (id) => {
            dispatch(credentials_1.removeCredential(id));
        },
        setCredential: (id, tag, value, changed) => {
            dispatch(credentials_1.setCredential(id, tag, value, changed));
        },
        setLastId: (lastid) => {
            dispatch(credentials_1.setLastId(lastid));
        },
        setActiveToken: (token) => {
            dispatch(token_1.setActiveToken(token));
        },
    };
}
exports.default = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(CredentialsList);
