"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const widgets_1 = require("@phosphor/widgets");
const coreutils_1 = require("@jupyterlab/coreutils");
const coreutils_2 = require("@phosphor/coreutils");
const React = require("react");
const ReactDOM = require("react-dom");
/**
 * The class name added to the extension.
 */
const CLASS_NAME = 'jp-IpyDashboard';
const DIRTY_CLASS = 'jp-mod-dirty';
class DashboardWidget extends widgets_1.Widget {
    constructor(context) {
        super();
        this._ready = new coreutils_2.PromiseDelegate();
        this.refInput = React.createRef();
        this.isReady = false;
        this.context = context;
        this.name = this.context.localPath.replace(/[&\/\\#,+()$~%.'":*?<>{}]/g, '');
        this._onTitleChanged();
        context.pathChanged.connect(this._onTitleChanged, this);
        this.context.ready.then(() => { this._onContextReady(); });
        this.context.ready.then(() => { this._handleDirtyState(); });
        this.addClass(CLASS_NAME);
        this.div = document.createElement('div');
        this.div.id = 'root' + this.name;
        this.div.setAttribute('tabindex', '0');
        this.node.appendChild(this.div);
        this.state = '';
        this._saveToContext = this._saveToContext.bind(this);
        this._loadFromContext = this._loadFromContext.bind(this);
    }
    /**
     * Handle `'activate-request'` messages.
     */
    onActivateRequest(msg) {
        this.div.focus();
    }
    /**
     * A message handler invoked on an `'after-attach'` message.
     */
    onAfterAttach(msg) {
        super.onAfterAttach(msg);
        if (this.isVisible) {
            this.update();
        }
    }
    onAfterShow(msg) {
        this._onContentChanged();
    }
    _onContextReady() {
        this.isReady = true;
        const contextModel = this.context.model;
        //; //--> stores in value as observalbestring: this.context.model.value
        console.log(this.context.model);
        // Set the editor model value.
        this._onContentChanged();
        contextModel.contentChanged.connect(this._onContentChanged, this);
        contextModel.stateChanged.connect(this._onModelStateChanged, this);
        this._ready.resolve(void 0);
    }
    /**
     * Handle a change to the title.
     */
    _onTitleChanged() {
        this.title.label = coreutils_1.PathExt.basename(this.context.localPath);
    }
    _onContentChanged() {
        if (this.isReady) {
            new Promise((resolve, reject) => {
                ReactDOM.render(React.createElement("div", null, "Hi"), document.getElementById('root' + this.name), () => {
                    resolve();
                });
            });
            //this._saveToContext();
        }
        ;
    }
    _saveToContext() {
        //console.log("saved!");
        this.context.model.fromString('{"value":"' + this.state + '"}');
        this.context.save();
    }
    _loadFromContext() {
        //let el: HTMLInputElement = document.getElementById('inputid')[0];
        this.refInput.current.value = this.context.model.toJSON()["value"];
    }
    _onModelStateChanged(sender, args) {
        if (args.name === 'dirty') {
            this._handleDirtyState();
        }
    }
    _handleDirtyState() {
        if (this.context.model.dirty) {
            this.title.className += ` ${DIRTY_CLASS}`;
        }
        else {
            this.title.className = this.title.className.replace(DIRTY_CLASS, '');
        }
    }
    /**
     * A promise that resolves when the csv viewer is ready.
     */
    get ready() {
        return this._ready.promise;
    }
}
exports.DashboardWidget = DashboardWidget;
